@@ -33,7 +33,6 @@
 #include "body_kick_to_corner.h"
 
 #include <rcsc/action/body_advance_ball.h>
-#include <rcsc/action/body_kick_multi_step.h>
 #include <rcsc/action/body_dribble.h>
 #include <rcsc/action/body_hold_ball.h>
 #include <rcsc/action/body_pass.h>
@@ -146,11 +145,11 @@ Bhv_BasicOffensiveKick::execute( rcsc::PlayerAgent * agent )
                                     "%s:%d: dribble to my body dir"
                                     ,__FILE__, __LINE__ );
                 agent->debugClient().addMessage( "OffKickDrib(1)" );
-                rcsc::Body_Dribble( body_dir_drib_target,
-                                    1.0,
-                                    rcsc::ServerParam::i().maxPower(),
-                                    2
-                                    ).execute( agent );
+                rcsc::Body_Dribble2008( body_dir_drib_target,
+                                        1.0,
+                                        rcsc::ServerParam::i().maxDashPower(),
+                                        2
+                                        ).execute( agent );
                 agent->setNeckAction( new rcsc::Neck_TurnToLowConfTeammate() );
                 return true;
             }
@@ -189,11 +188,11 @@ Bhv_BasicOffensiveKick::execute( rcsc::PlayerAgent * agent )
                                 drib_target.x, drib_target.y,
                                 max_dash_step );
             agent->debugClient().addMessage( "OffKickDrib(2)" );
-            rcsc::Body_Dribble( drib_target,
-                                1.0,
-                                rcsc::ServerParam::i().maxPower(),
-                                std::min( 5, max_dash_step )
-                                ).execute( agent );
+            rcsc::Body_Dribble2008( drib_target,
+                                    1.0,
+                                    rcsc::ServerParam::i().maxDashPower(),
+                                    std::min( 5, max_dash_step )
+                                    ).execute( agent );
         }
         else
         {
@@ -202,11 +201,11 @@ Bhv_BasicOffensiveKick::execute( rcsc::PlayerAgent * agent )
                                 ,__FILE__, __LINE__,
                                 drib_target.x, drib_target.y );
             agent->debugClient().addMessage( "OffKickDrib(3)" );
-            rcsc::Body_Dribble( drib_target,
-                                1.0,
-                                rcsc::ServerParam::i().maxPower(),
-                                2
-                                ).execute( agent );
+            rcsc::Body_Dribble2008( drib_target,
+                                    1.0,
+                                    rcsc::ServerParam::i().maxDashPower(),
+                                    2
+                                    ).execute( agent );
 
         }
         agent->setNeckAction( new rcsc::Neck_TurnToLowConfTeammate() );
@@ -221,11 +220,11 @@ Bhv_BasicOffensiveKick::execute( rcsc::PlayerAgent * agent )
                             ,__FILE__, __LINE__,
                             drib_target.x, drib_target.y );
         agent->debugClient().addMessage( "OffKickDrib(4)" );
-        rcsc::Body_Dribble( drib_target,
-                            1.0,
-                            rcsc::ServerParam::i().maxPower() * 0.4,
-                            1
-                            ).execute( agent );
+        rcsc::Body_Dribble2008( drib_target,
+                                1.0,
+                                rcsc::ServerParam::i().maxDashPower() * 0.4,
+                                1
+                                ).execute( agent );
         agent->setNeckAction( new rcsc::Neck_TurnToLowConfTeammate() );
         return true;
     }
@@ -251,11 +250,11 @@ Bhv_BasicOffensiveKick::execute( rcsc::PlayerAgent * agent )
                             ,__FILE__, __LINE__,
                             drib_target.x, drib_target.y );
         agent->debugClient().addMessage( "OffKickDrib(5)" );
-        rcsc::Body_Dribble( drib_target,
-                            1.0,
-                            rcsc::ServerParam::i().maxPower() * 0.2,
-                            1
-                            ).execute( agent );
+        rcsc::Body_Dribble2008( drib_target,
+                                1.0,
+                                rcsc::ServerParam::i().maxDashPower() * 0.2,
+                                1
+                                ).execute( agent );
         agent->setNeckAction( new rcsc::Neck_TurnToLowConfTeammate() );
         return true;
     }
