@@ -32,11 +32,11 @@
 
 #include "bhv_goalie_basic_move.h"
 
-#include <rcsc/action/basic_actions.h>
 #include <rcsc/action/body_clear_ball.h>
-#include <rcsc/action/body_kick_two_step.h>
 #include <rcsc/action/body_pass.h>
-#include <rcsc/action/intention_kick.h>
+
+#include <rcsc/action/basic_actions.h>
+#include <rcsc/action/body_kick_one_step.h>
 #include <rcsc/action/neck_scan_field.h>
 
 #include <rcsc/player/player_agent.h>
@@ -49,7 +49,7 @@
 /*-------------------------------------------------------------------*/
 /*!
   execute action
- */
+*/
 bool
 Bhv_GoalieFreeKick::execute( rcsc::PlayerAgent * agent )
 {
@@ -58,15 +58,13 @@ Bhv_GoalieFreeKick::execute( rcsc::PlayerAgent * agent )
     static int s_second_wait_count = 0;
 
     rcsc::dlog.addText( rcsc::Logger::TEAM,
-                "%s:%d: Act_GoalieFreeKick"
-                ,__FILE__, __LINE__ );
+                        __FILE__": Bhf_GoalieFreeKick" );
     if ( agent->world().gameMode().type() != rcsc::GameMode::GoalieCatch_
          || agent->world().gameMode().side() != agent->world().ourSide()
          || ! agent->world().self().isKickable() )
     {
         rcsc::dlog.addText( rcsc::Logger::TEAM,
-                      "%s:%d: Act_GoalieFreeKick. Not a goalie catch mode"
-                      ,__FILE__, __LINE__ );
+                            __FILE__": Bhv_GoalieFreeKick. Not a goalie catch mode" );
 
         Bhv_GoalieBasicMove().execute( agent );
         return true;
@@ -76,7 +74,7 @@ Bhv_GoalieFreeKick::execute( rcsc::PlayerAgent * agent )
     const long time_diff
         = agent->world().time().cycle()
         - agent->effector().getCatchTime().cycle();
-        //- M_catch_time.cycle();
+    //- M_catch_time.cycle();
 
     // reset flags & wait
     if ( time_diff <= 2 )
@@ -93,21 +91,23 @@ Bhv_GoalieFreeKick::execute( rcsc::PlayerAgent * agent )
     if ( ! s_first_move )
     {
         //rcsc::Vector2D move_target( rcsc::ServerParam::i().ourPenaltyAreaLine() - 0.8, 0.0 );
-        rcsc::Vector2D move_target( rcsc::ServerParam::i().ourPenaltyAreaLineX() - 0.8,
+        rcsc::Vector2D move_target( rcsc::ServerParam::i().ourPenaltyAreaLineX() - 1.5,
                                     agent->world().ball().pos().y > 0.0 ? -13.0 : 13.0 );
         //rcsc::Vector2D move_target( -45.0, 0.0 );
         s_first_move = true;
         s_second_move = false;
         s_second_wait_count = 0;
         agent->doMove( move_target.x, move_target.y );
+        agent->setNeckAction( new rcsc::Neck_ScanField );
         return true;
     }
 
     // after first move
     // check stamina recovery or wait teammate
     rcsc::Rect2D our_pen( rcsc::Vector2D( -52.5, -40.0 ),
-                          rcsc::Vector2D( -33.0, 40.0 ) );
+                          rcsc::Vector2D( -36.0, 40.0 ) );
     if ( time_diff < 50
+         || agent->world().setplayCount() < 3
          || ( time_diff < rcsc::ServerParam::i().dropBallTime() - 15
               && ( agent->world().self().stamina() < rcsc::ServerParam::i().staminaMax() * 0.9
                    || agent->world().existTeammateIn( our_pen, 20, true )
@@ -124,6 +124,7 @@ Bhv_GoalieFreeKick::execute( rcsc::PlayerAgent * agent )
     {
         rcsc::Vector2D kick_point = getKickPoint( agent );
         agent->doMove( kick_point.x, kick_point.y );
+        agent->setNeckAction( new rcsc::Neck_ScanField );
         s_second_move = true;
         s_second_wait_count = 0;
         return true;
@@ -153,11 +154,10 @@ Bhv_GoalieFreeKick::execute( rcsc::PlayerAgent * agent )
 /*-------------------------------------------------------------------*/
 /*!
 
- */
+*/
 rcsc::Vector2D
 Bhv_GoalieFreeKick::getKickPoint( const rcsc::PlayerAgent * agent )
 {
-#if 1
     static const double base_x = -43.0;
     static const double base_y = 10.0;
 
@@ -196,54 +196,20 @@ Bhv_GoalieFreeKick::getKickPoint( const rcsc::PlayerAgent * agent )
     }
 
     return best_pos;
-#else
-    static const double base_x = -43.0;
-    static const double base_y = 10.0;
-
-    const rcsc::Vector2D left_candidate( base_x, base_y );
-    const rcsc::Vector2D right_candidate( base_x, -base_y );
-
-    double left_congestion = 0.0;
-    double right_congestion = 0.0;
-
-    const rcsc::PlayerPtrCont::const_iterator opps_end
-        = agent->world().getOpponentsFromSelf().end();
-    for ( rcsc::PlayerPtrCont::const_iterator it
-              = agent->world().getOpponentsFromSelf().begin();
-          it != opps_end;
-          ++it )
-    {
-        left_congestion += 1.0 / (*it)->pos().dist2( left_candidate );
-        right_congestion += 1.0 / (*it)->pos().dist2( right_candidate );
-    }
-
-    if ( left_congestion < right_congestion )
-    {
-        return left_candidate;
-    }
-    else
-    {
-        return right_candidate;
-    }
-#endif
 }
 
 /*-------------------------------------------------------------------*/
 /*!
 
- */
+*/
 void
 Bhv_GoalieFreeKick::doKick( rcsc::PlayerAgent * agent )
 {
     rcsc::Vector2D target_point;
-    double ball_speed;
+    double pass_speed = 0.0;
 
-    if  ( rcsc::Body_Pass::get_best_pass( agent->world(),
-                                          &target_point,
-                                          &ball_speed,
-                                          NULL )
-          && target_point.dist( rcsc::Vector2D( -50.0, 0.0 ) ) > 20.0
-          )
+    if  ( rcsc::Body_Pass::get_best_pass( agent->world(), &target_point, &pass_speed, NULL )
+          && target_point.dist( rcsc::Vector2D( -50.0, 0.0 ) ) > 20.0 )
     {
         double opp_dist = 100.0;
         const rcsc::PlayerObject * opp
@@ -251,21 +217,12 @@ Bhv_GoalieFreeKick::doKick( rcsc::PlayerAgent * agent )
         agent->debugClient().addMessage( "GKickOppDist%.1f", opp ? opp_dist : 1000.0 );
         if ( ! opp || opp_dist > 3.0 )
         {
-            // enforce one step kick
-            rcsc::Body_KickTwoStep( target_point,
-                                    ball_speed,
-                                    true
-                                    ).execute( agent ); // enforce mode
-            agent->setIntention
-                ( new rcsc::IntentionKick( target_point,
-                                           rcsc::ServerParam::i().ballSpeedMax(),
-                                           1,    // one step
-                                           true, // enforde
-                                           agent->world().time() ) );
+            rcsc::Body_KickOneStep( target_point,
+                                    pass_speed ).execute( agent );
             rcsc::dlog.addText( rcsc::Logger::TEAM,
-                        "%s:%d: register goalie kick intention. to (%f, %f)"
-                        ,__FILE__, __LINE__,
-                        target_point.x, target_point.y );
+                                __FILE__": register goalie kick intention. to (%.1f, %.1f)",
+                                target_point.x,
+                                target_point.y );
             agent->setNeckAction( new rcsc::Neck_ScanField() );
             return;
         }
@@ -278,11 +235,22 @@ Bhv_GoalieFreeKick::doKick( rcsc::PlayerAgent * agent )
 /*-------------------------------------------------------------------*/
 /*!
 
- */
+*/
 void
 Bhv_GoalieFreeKick::doWait( rcsc::PlayerAgent * agent )
 {
+    const rcsc::WorldModel & wm = agent->world();
     rcsc::Vector2D face_target( 0.0, 0.0 );
+
+    if ( wm.self().pos().x > rcsc::ServerParam::i().ourPenaltyAreaLineX()
+         - rcsc::ServerParam::i().ballSize()
+         - wm.self().playerType().playerSize()
+         - 0.5 )
+    {
+        face_target.assign( rcsc::ServerParam::i().ourPenaltyAreaLineX() - 1.0,
+                            0.0 );
+    }
+
     rcsc::Body_TurnToPoint( face_target ).execute( agent );
     agent->setNeckAction( new rcsc::Neck_ScanField() );
 }
