@@ -41,7 +41,7 @@
 #include <rcsc/action/body_go_to_point.h>
 #include <rcsc/action/body_intercept.h>
 #include <rcsc/action/body_kick_one_step.h>
-#include <rcsc/action/body_kick_multi_step.h>
+#include <rcsc/action/body_smart_kick.h>
 #include <rcsc/action/body_stop_dash.h>
 #include <rcsc/action/body_stop_ball.h>
 #include <rcsc/action/neck_scan_field.h>
@@ -184,7 +184,7 @@ Bhv_PenaltyKick::doKickerWait( rcsc::PlayerAgent * agent )
         // no dodge
         rcsc::Body_GoToPoint( wait_pos,
                               0.7,
-                              rcsc::ServerParam::i().maxPower()
+                              rcsc::ServerParam::i().maxDashPower()
                               ).execute( agent );
         agent->setNeckAction( new rcsc::Neck_TurnToRelative( 0.0 ) );
     }
@@ -279,11 +279,11 @@ Bhv_PenaltyKick::doKicker( rcsc::PlayerAgent * agent )
     // get ball
     if ( ! agent->world().self().isKickable() )
     {
-        if ( ! rcsc::Body_Intercept().execute( agent ) )
+        if ( ! rcsc::Body_Intercept2008().execute( agent ) )
         {
             rcsc::Body_GoToPoint( agent->world().ball().pos(),
                                   0.4,
-                                  rcsc::ServerParam::i().maxPower()
+                                  rcsc::ServerParam::i().maxDashPower()
                                   ).execute( agent );
         }
 
@@ -337,7 +337,7 @@ Bhv_PenaltyKick::doOneKickShoot( rcsc::PlayerAgent * agent )
     {
         rcsc::Body_GoToPoint( agent->world().ball().pos(),
                               0.4,
-                              rcsc::ServerParam::i().maxPower()
+                              rcsc::ServerParam::i().maxDashPower()
                               ).execute( agent );
         agent->setNeckAction( new rcsc::Neck_TurnToBall() );
         return true;
@@ -424,7 +424,10 @@ Bhv_PenaltyKick::doShoot( rcsc::PlayerAgent * agent )
 
     if ( getShootTarget( agent, &shot_point, &shot_speed ) )
     {
-        rcsc::Body_KickMultiStep( shot_point, shot_speed).execute( agent );
+        rcsc::Body_SmartKick( shot_point,
+                              shot_speed,
+                              shot_speed * 0.96,
+                              2 ).execute( agent );
         agent->setNeckAction( new rcsc::Neck_TurnToPoint( shot_point ) );
         return true;
     }
@@ -620,7 +623,7 @@ Bhv_PenaltyKick::doDribble( rcsc::PlayerAgent * agent )
 
     const double base_target_abs_y = rcsc::ServerParam::i().goalHalfWidth() + 4.0;
     rcsc::Vector2D drib_target = goal_c;
-    double drib_power = rcsc::ServerParam::i().maxPower();
+    double drib_power = rcsc::ServerParam::i().maxDashPower();
     int drib_dashes = 6;
 
     /////////////////////////////////////////////////
@@ -738,14 +741,14 @@ Bhv_PenaltyKick::doDribble( rcsc::PlayerAgent * agent )
                 ( 0.5,
                   target_rel.r(),
                   rcsc::ServerParam::i().ballDecay() );
-            //= rcsc::required_first_speed( target_rel.r(),
-            //rcsc::ServerParam::i().ballDecay(),
-            //0.5 );
+
             first_speed = std::min( first_speed, rcsc::ServerParam::i().ballSpeedMax() );
-            rcsc::Body_KickMultiStep( drib_target, first_speed ).execute( agent );
+            rcsc::Body_SmartKick( drib_target,
+                                  first_speed,
+                                  first_speed * 0.96,
+                                  3 ).execute( agent );
             rcsc::dlog.addText( rcsc::Logger::TEAM,
-                                "%s:%d: kick. to=(%f, %f) first_speed=%f"
-                                ,__FILE__, __LINE__,
+                                __FILE__": kick. to=(%.1f, %.1f) first_speed=%.1f",
                                 drib_target.x, drib_target.y, first_speed );
         }
         else if ( ( agent->world().ball().rpos()
@@ -770,12 +773,12 @@ Bhv_PenaltyKick::doDribble( rcsc::PlayerAgent * agent )
             dodge_mode = false;
         }
 
-        rcsc::Body_Dribble( drib_target,
-                            2.0,
-                            drib_power,
-                            drib_dashes,
-                            dodge_mode
-                            ).execute( agent );
+        rcsc::Body_Dribble2008( drib_target,
+                                2.0,
+                                drib_power,
+                                drib_dashes,
+                                dodge_mode
+                                ).execute( agent );
     }
 
     if ( opp_goalie )
@@ -820,7 +823,7 @@ Bhv_PenaltyKick::doGoalieWait( rcsc::PlayerAgent * agent )
     {
         rcsc::Body_GoToPoint( wait_pos,
                               0.5,
-                              rcsc::ServerParam::i().maxPower()
+                              rcsc::ServerParam::i().maxDashPower()
                               ).execute( agent );
         agent->setNeckAction( new rcsc::Neck_TurnToPoint( face_point ) );
     }
@@ -844,7 +847,7 @@ Bhv_PenaltyKick::doGoalieSetup( rcsc::PlayerAgent * agent )
 
     if ( rcsc::Body_GoToPoint( move_point,
                                0.5,
-                               rcsc::ServerParam::i().maxPower()
+                               rcsc::ServerParam::i().maxDashPower()
                                ).execute( agent ) )
     {
         agent->setNeckAction( new rcsc::Neck_TurnToBall() );
@@ -878,16 +881,16 @@ Bhv_PenaltyKick::doGoalie( rcsc::PlayerAgent * agent )
 
     ///////////////////////////////////////////////
     // check if catchabale
-    rcsc::Rect2D our_penalty( -rcsc::ServerParam::i().pitchHalfLength(),
-                              -rcsc::ServerParam::i().penaltyAreaHalfWidth() + 1.0,
-                              rcsc::ServerParam::i().penaltyAreaLength() - 1.0,
-                              rcsc::ServerParam::i().penaltyAreaWidth() - 2.0 );
+    rcsc::Rect2D our_penalty( rcsc::Vector2D( -rcsc::ServerParam::i().pitchHalfLength(),
+                                              -rcsc::ServerParam::i().penaltyAreaHalfWidth() + 1.0 ),
+                              rcsc::Size2D( rcsc::ServerParam::i().penaltyAreaLength() - 1.0,
+                                            rcsc::ServerParam::i().penaltyAreaWidth() - 2.0 ) );
     if ( state->onfieldSide() != agent->world().ourSide() )
     {
-        our_penalty.assign( rcsc::ServerParam::i().theirPenaltyAreaLineX() + 1.0,
-                            -rcsc::ServerParam::i().penaltyAreaHalfWidth() + 1.0,
-                            rcsc::ServerParam::i().penaltyAreaLength() - 1.0,
-                            rcsc::ServerParam::i().penaltyAreaWidth() - 2.0 );
+        our_penalty.assign( rcsc::Vector2D( rcsc::ServerParam::i().theirPenaltyAreaLineX() + 1.0,
+                                            -rcsc::ServerParam::i().penaltyAreaHalfWidth() + 1.0 ),
+                            rcsc::Size2D( rcsc::ServerParam::i().penaltyAreaLength() - 1.0,
+                                          rcsc::ServerParam::i().penaltyAreaWidth() - 2.0 ) );
     }
 
     if ( agent->world().ball().distFromSelf()
@@ -940,25 +943,26 @@ Bhv_PenaltyKick::doGoalieBasicMove( rcsc::PlayerAgent * agent )
 {
     const rcsc::PenaltyKickState * state = agent->world().penaltyKickState();
 
-    rcsc::Rect2D our_penalty( -rcsc::ServerParam::i().pitchHalfLength(),
-                              -rcsc::ServerParam::i().penaltyAreaHalfWidth() + 1.0,
-                              rcsc::ServerParam::i().penaltyAreaLength() - 1.0,
-                              rcsc::ServerParam::i().penaltyAreaWidth() - 2.0 );
+    rcsc::Rect2D our_penalty( rcsc::Vector2D( -rcsc::ServerParam::i().pitchHalfLength(),
+                                              -rcsc::ServerParam::i().penaltyAreaHalfWidth() + 1.0 ),
+                              rcsc::Size2D( rcsc::ServerParam::i().penaltyAreaLength() - 1.0,
+                                            rcsc::ServerParam::i().penaltyAreaWidth() - 2.0 ) );
     if ( state->onfieldSide() != agent->world().ourSide() )
     {
-        our_penalty.assign( rcsc::ServerParam::i().theirPenaltyAreaLineX() + 1.0,
-                            -rcsc::ServerParam::i().penaltyAreaHalfWidth() + 1.0,
-                            rcsc::ServerParam::i().penaltyAreaLength() - 1.0,
-                            rcsc::ServerParam::i().penaltyAreaWidth() - 2.0);
+        our_penalty.assign( rcsc::Vector2D( rcsc::ServerParam::i().theirPenaltyAreaLineX() + 1.0,
+                                            -rcsc::ServerParam::i().penaltyAreaHalfWidth() + 1.0 ),
+                            rcsc::Size2D( rcsc::ServerParam::i().penaltyAreaLength() - 1.0,
+                                          rcsc::ServerParam::i().penaltyAreaWidth() - 2.0 ) );
     }
 
     ////////////////////////////////////////////////////////////////////////
     // get active interception catch point
-    rcsc::Vector2D move_pos = agent->world().interceptTable()->selfInterceptPoint();
+    const int self_min = agent->world().interceptTable()->selfReachCycle();
+    rcsc::Vector2D move_pos = agent->world().ball().inertiaPoint( self_min );
 
     if ( our_penalty.contains( move_pos ) )
     {
-        if ( rcsc::Body_Intercept( false ).execute( agent ) )
+        if ( rcsc::Body_Intercept2008( false ).execute( agent ) )
         {
             agent->setNeckAction( new rcsc::Neck_TurnToBall() );
             return true;
@@ -1000,7 +1004,7 @@ Bhv_PenaltyKick::doGoalieBasicMove( rcsc::PlayerAgent * agent )
 
     if ( ! rcsc::Body_GoToPoint( move_pos,
                                  0.5,
-                                 rcsc::ServerParam::i().maxPower()
+                                 rcsc::ServerParam::i().maxDashPower()
                                  ).execute( agent ) )
     {
         // already there
@@ -1188,7 +1192,7 @@ Bhv_PenaltyKick::doGoalieSlideChase( rcsc::PlayerAgent * agent )
     if ( ! intersection.valid()
          || ! ball_ray.inRightDir( intersection ) )
     {
-        rcsc::Body_Intercept( false ).execute( agent ); // goalie mode
+        rcsc::Body_Intercept2008( false ).execute( agent ); // goalie mode
         agent->setNeckAction( new rcsc::Neck_TurnToBall() );
         return true;
     }
@@ -1202,7 +1206,7 @@ Bhv_PenaltyKick::doGoalieSlideChase( rcsc::PlayerAgent * agent )
     }
 
     rcsc::AngleDeg angle = ( intersection - agent->world().self().pos() ).th();
-    double dash_power = rcsc::ServerParam::i().maxPower();
+    double dash_power = rcsc::ServerParam::i().maxDashPower();
     if ( ( angle - agent->world().self().body() ).abs() > 90.0 )
     {
         dash_power *= -1.0;
