@@ -80,6 +80,28 @@ main( int argc, char **argv )
         return EXIT_FAILURE;
     }
 
+    /*
+      You should add your copyright message here.
+     */
+    // std::cout << "*****************************************************************\n"
+    //           << " This program is modified by <Team Name>\n"
+    //           << " Copyright 20xx. <Your name>.\n"
+    //           << " <Affiliation>\n"
+    //           << " All rights reserved.\n"
+    //           << "*****************************************************************\n"
+    //           << std::flush;
+
+    /*
+      Do NOT remove the following copyright notice!
+     */
+    std::cout << "*****************************************************************\n"
+              << " This program is based on agent2d created by Hidehisa Akiyama.\n"
+              << " Copyright 2006 - 2009. Hidehisa Akiyama.\n"
+              << " National Institute of Advanced Industrial Science and Technology\n"
+              << " All rights reserved.\n"
+              << "*****************************************************************\n"
+              << std::flush;
+
     client.run( &agent );
 
     return EXIT_SUCCESS;
