@@ -39,8 +39,8 @@ private:
 public:
     explicit
     RoleGoalie( boost::shared_ptr< const rcsc::Formation > f )
-        : SoccerRole( f )
-        , M_last_goalie_kick_time( 0, 0 )
+        : SoccerRole( f ),
+          M_last_goalie_kick_time( 0, 0 )
       { }
 
     ~RoleGoalie()
@@ -56,11 +56,13 @@ public:
       {
           return std::string( "Goalie" );
       }
+
     static
     SoccerRole * create( boost::shared_ptr< const rcsc::Formation > f )
       {
-          return ( new RoleGoalie( f ) );
+          return new RoleGoalie( f );
       }
+
 private:
     void doKick( rcsc::PlayerAgent * agent );
     void doMove( rcsc::PlayerAgent * agent );
