@@ -52,7 +52,7 @@
 #include <iostream>
 #include <cstdio>
 
-//#include "team_logo.xpm"
+#include "team_logo.xpm"
 
 /////////////////////////////////////////////////////////
 
@@ -203,33 +203,50 @@ SampleCoach::~SampleCoach()
 bool
 SampleCoach::initImpl( rcsc::CmdLineParser & cmd_parser )
 {
-    rcsc::ParamMap my_params;
+    bool result = rcsc::CoachAgent::initImpl( cmd_parser );
 
+    rcsc::ParamMap my_params;
 #if 0
     std::string formation_conf;
+    int role_number = 0;
+    bool use_clang = false;
     my_map.add()
-        ( &conf_path, "fconf" )
+        ( "fconf", "", &formation_conf, "set the formation configuration file." )
+        ( "strategy-number", "", &strategy_number, "set the strategy number." )
+        ( "use_clang", "", rcsc::BoolSwitch( &use_clang ), "" )
         ;
 #endif
+    cmd_parser.parse( my_params );
 
-    if ( ! rcsc::CoachAgent::initImpl( cmd_parser ) )
+    if ( cmd_parser.count( "help" ) )
     {
         my_params.printHelp( std::cout );
-        M_client->setServerAlive( false );
         return false;
     }
 
     if ( cmd_parser.failed() )
     {
-        std::cerr << "coach: ***WARNING*** detected invalid options: ";
+        std::cerr << "coach: ***WARNING*** detected unsupported options: ";
         cmd_parser.print( std::cerr );
         std::cerr << std::endl;
     }
 
-    //if ( config().useTeamGraphic() )
-    //{
-    //    M_team_graphic.createXpmTiles( team_logo_xpm );
-    //}
+    if ( ! result )
+    {
+        return false;
+    }
+
+    if ( config().useTeamGraphic() )
+    {
+        if ( config().teamGraphicFile().empty() )
+        {
+            M_team_graphic.createXpmTiles( team_logo_xpm );
+        }
+        else
+        {
+            M_team_graphic.readXpmFile( config().teamGraphicFile().c_str() );
+        }
+    }
 
     //////////////////////////////////////////////////////////////////
     // Add your code here.
@@ -652,8 +669,8 @@ SampleCoach::sayPlayerTypes()
     for ( int unum = 1; unum <= 11; ++unum )
     {
         char buf[8];
-        std::snprintf( buf, 8, "(%d %d)",
-                       unum, M_opponent_player_types[unum - 1] );
+        snprintf( buf, 8, "(%d %d)",
+                  unum, M_opponent_player_types[unum - 1] );
         msg += buf;
     }
 
