@@ -33,9 +33,10 @@
 #include <rcsc/trainer/trainer_command.h>
 #include <rcsc/trainer/trainer_config.h>
 #include <rcsc/coach/global_world_model.h>
-#include <rcsc/param/player_param.h>
-#include <rcsc/param/player_type.h>
-#include <rcsc/param/server_param.h>
+#include <rcsc/common/basic_client.h>
+#include <rcsc/common/player_param.h>
+#include <rcsc/common/player_type.h>
+#include <rcsc/common/server_param.h>
 #include <rcsc/param/param_map.h>
 #include <rcsc/param/cmd_line_parser.h>
 #include <rcsc/random.h>
@@ -64,31 +65,36 @@ SampleTrainer::~SampleTrainer()
 
  */
 bool
-SampleTrainer::doInit( rcsc::CmdLineParser & cmd_parser )
+SampleTrainer::initImpl( rcsc::CmdLineParser & cmd_parser )
 {
-    rcsc::ParamMap my_params;
+    bool result = rcsc::TrainerAgent::initImpl( cmd_parser );
 
+    rcsc::ParamMap my_params;
 #if 0
     std::string formation_conf;
     my_map.add()
         ( &conf_path, "fconf" )
         ;
 #endif
+    cmd_parser.parse( my_params );
 
-    if ( ! TrainerAgent::doInit( cmd_parser ) )
+    if ( cmd_parser.count( "help" ) )
     {
         my_params.printHelp( std::cout );
-        setServerAlive( false );
         return false;
     }
 
     if ( cmd_parser.failed() )
     {
-        std::cerr << "trainer: ***WARNING*** detected invalid options: ";
+        std::cerr << "trainer: ***WARNING*** detected unsupported options: ";
         cmd_parser.print( std::cerr );
         std::cerr << std::endl;
     }
 
+    if ( ! result )
+    {
+        return false;
+    }
 
     //////////////////////////////////////////////////////////////////
     // Add your code here.
@@ -103,7 +109,7 @@ SampleTrainer::doInit( rcsc::CmdLineParser & cmd_parser )
 
  */
 void
-SampleTrainer::doAction()
+SampleTrainer::actionImpl()
 {
     //////////////////////////////////////////////////////////////////
     // This function is a sample trainer action.
@@ -163,7 +169,7 @@ SampleTrainer::sampleAction()
         }
         doSay( "move player" );
         s_state = 2;
-        std::cout << "trainer: doAction set ball center" << std::endl;
+        std::cout << "trainer: actionImpl set ball center" << std::endl;
         break;
     case 2:
         ++s_wait_counter;
@@ -181,7 +187,7 @@ SampleTrainer::sampleAction()
                         velocity );
             s_state = 0;
             s_wait_counter = 0;
-            std::cout << "trainer: doAction start ball" << std::endl;
+            std::cout << "trainer: actionImpl start ball" << std::endl;
         }
         break;
 
