@@ -71,8 +71,7 @@ const std::string Strategy::GOAL_KICK_OUR_CONF = "goal-kick-our.conf";
 const std::string Strategy::GOALIE_CATCH_OPP_CONF = "goalie-catch-opp.conf";
 const std::string Strategy::GOALIE_CATCH_OUR_CONF = "goalie-catch-our.conf";
 
-const std::string Strategy::DEFENSE_FORMATION_CONF = "defense-formation.conf";
-const std::string Strategy::OFFENSE_FORMATION_CONF = "offense-formation.conf";
+const std::string Strategy::NORMAL_FORMATION_CONF = "normal-formation.conf";
 const std::string Strategy::KICKIN_OUR_FORMATION_CONF = "kickin-our-formation.conf";
 const std::string Strategy::SETPLAY_OUR_FORMATION_CONF = "setplay-our-formation.conf";
 
@@ -160,19 +159,12 @@ Strategy::read( const std::string & config_dir )
 
     ///////////////////////////////////////////////////////////
     // offense area
-    M_offense_formation = readFormation( configpath + OFFENSE_FORMATION_CONF );
-    if ( ! M_offense_formation )
+    M_normal_formation = readFormation( configpath + NORMAL_FORMATION_CONF );
+    if ( ! M_normal_formation )
     {
         std::cerr << "Failed to read offense formation" << std::endl;
         return false;
     }
-    // defense area
-    M_defense_formation = readFormation( configpath + DEFENSE_FORMATION_CONF );
-    if ( ! M_defense_formation )
-    {
-        std::cerr << "Failed to read defense formation" << std::endl;
-        return false;
-    }
     // kick_in our
     M_kickin_our_formation = readFormation( configpath + KICKIN_OUR_FORMATION_CONF );
     if ( ! M_kickin_our_formation )
@@ -588,14 +580,7 @@ Strategy::getFormation( const rcsc::WorldModel & world ) const
         return M_setplay_our_formation;
     }
 
-    if ( world.ball().pos().x > 0.0 )
-    {
-        return M_offense_formation;
-    }
-    else
-    {
-        return M_defense_formation;
-    }
+    return M_normal_formation;
 }
 
 /*-------------------------------------------------------------------*/
